Court of Appeals Opinions | Tennessee Administrative Office of the Courts

# Tennessee Administrative Office of the Courts

### SEARCH TNCOURTS.GOV:

Search this site:
Administrative Office of the Courts
511 Union Street, Suite 600
Nashville, TN 37219
(615) 741-2687
(800) 448-7970

© 2013 Tennessee Courts System

## Court of Appeals Opinions

Court
County
Authoring Judge
Originating Judge
Date Filter
Format: 08/30/2013
And:
Format: 08/30/2013
Case Number
Case Name
keyword search
Sort by:
Order:

James M. Bowley, et al v. Richard Lane, et al E2012-00134-COA-R3-CV Authoring Judge: Judge D. Michael Swiney Trial Court Judge: Judge Lawrence H. Puckett James M. Bowley and Barbara A. Bowley (“Plaintiffs”) sued Richard Lane, Alvin Butler, and Danny Nicholson (“Defendants”) alleging defective construction of a log home built by Defendants for Plaintiffs. After trial, the Trial Court entered judgment upon the jury’s verdict finding and holding, inter alia, that Defendants had breached the implied warranty of habitability, and that Plaintiffs had sustained $50,000 in damages as a result of this breach. Defendants appeal to this Court raising an issue regarding whether the Trial Court erred in approving the verdict and denying their motion for new trial or for remittitur. Plaintiffs also raise an issue alleging that the evidence does not support the verdict. We find and hold that material evidence supports the jury’s verdict, and further find no error in the Trial Court’s denial of Defendants’ motion for new trial or for remittitur, and the Trial Court’s denial of Plaintiffs’ motion for new trial or for additur. We affirm. | Monroe County | Court of Appeals | 08/29/13 |  |
Kelly Weed v. First Acceptance Insurance Company of Tennessee E2013-00150-COA-R3-CV Authoring Judge: Presiding Judge Charles D. Susano, Jr. Trial Court Judge: Judge Richard R. Vance This appeal involves the interpretation of an exclusionary clause in an automobile casualty insurance policy. The policy excluded coverage for a loss resulting from an accident occurring while the vehicle was being driven by an unlisted driver who “is a regular or frequent operator of” an insured vehicle. Caleb Jenkins, who was not listed in the policy as a “driver,” was involved in an accident while driving the vehicle of Kelly Weed (“Insured”). Insured brought suit after First Acceptance Insurance Company of Tennessee, Inc., (“Insurer”) denied her claim. Insurer moved for summary judgment, alleging that Jenkins was a regular and frequent operator of Insured’s vehicle. Based on Insured’s statement that Jenkins was a “fairly regular” driver of her vehicle who had been driving it once or twice a week for six months, the trial court denied coverage and granted Insurer summary judgment. We affirm the trial court’s judgment that the policy excluded coverage because Insured’s admission establishes that Jenkins was a “regular or frequent operator” of her vehicle. | Sevier County | Court of Appeals | 08/29/13 |  |
Timothy L. Wilson v. Hank E. Sledge, Jr., et al. W2012-00513-COA-R3-CV Authoring Judge: Judge David R. Farmer Trial Court Judge: Judge John R. McCarroll, Jr. The trial court dismissed this action for professional malpractice based upon the running of the statute of limitations. We affirm. | Shelby County | Court of Appeals | 08/29/13 |  |
Sheila Dunlap v. Laurel Manor Health Care, Inc. E2012-02432-COA-R3-CV Authoring Judge: Presiding Judge Charles D. Susano, Jr. Trial Court Judge: Judge John D. McAfee Sheila Dunlap (“plaintiff”) brought this action alleging liability for the wrongful death of her daughter (“deceased”) on the part of the nursing home operated by Laurel Manor Health Care, Inc. (“defendant”) where deceased was living. Although the allegations of the complaint were couched in terms of ordinary negligence, the trial court determined that the cause of action was one for medical malpractice. The court dismissed the complaint for failure to comply with Tenn. Code Ann. § 29-26-122, which requires the filing a certificate of good faith with a medical malpractice complaint. We hold that the plaintiff’s claims that the nursing home failed to properly administer medication and a medical device prescribed by a physician, and failed to monitor the medical condition of the deceased at all times prior to her death, sound in medical malpractice. Consequently, we affirm the judgment of the trial court. | Claiborne County | Court of Appeals | 08/29/13 |  |
Raleigh Court Condominiums, Homeowners' Association, Inc. v. E. Doyle Johnson Construction Co., et al E2012-02474-COA-R3-CV Authoring Judge: Judge John W. McClarty Trial Court Judge: Judge Harold Wimberly Homeowners’ association filed suit against general contractor because of drainage issues alleging fraud, negligent misrepresentation, negligence, violations of the Tennessee Consumer Protection Act, and breach of the implied warranty of “good and workmanlike” construction. The trial court found in favor of homeowners’ association. The general contractor appeals. We affirm. | Knox County | Court of Appeals | 08/29/13 |  |
Aubrey Owens & The Estate of Louis Gernt v. Aleeta Tipton Evans, Timothy L. Goad et al. M2013-00239-COA-R3-CV Authoring Judge: Presiding Judge Patricia J. Cottrell Trial Court Judge: Judge Jon Kerry Blackwood This is an appeal from a judgment entered against one of four defendants. Because the judgment appealed does not resolve all the claims between all the parties, we dismiss the appeal for lack of a final judgment. | Fentress County | Court of Appeals | 08/28/13 |  |
Amanda Marie Sykes v. Joshua Neal Sykes - Concur/Dissent M2012-01146-COA-R3-CV Authoring Judge: Judge Patricia J. Cottrell Trial Court Judge: Chancellor Stella L. Hargrove This appeal involves a judgment by the trial court that dismissed two motions filed by Mother. The first was the Motion to Alter or Amend the trial court’s decision denying the Petition to Set Support. That petition was denied on the basis that no significant variance existed. The second was Mother’s motion for relief pursuant to Tenn. R. Civ. P. 60.02. That motion was directed to the original decree of divorce and, more specifically, to the original child support established in the parenting plan. | Maury County | Court of Appeals | 08/28/13 |  |
Amanda Marie Sykes v. Joshua Neal Sykes M2012-01146-COA-R3-CV Authoring Judge: Judge Richard H. Dinkins Trial Court Judge: Chancellor Stella L. Hargrove In this divorce proceeding, Mother and Father entered into a Marital Dissolution Agreement and Permanent Parenting Plan, which were incorporated into the final decree of divorce; the parties shared equal parenting time with their two children and neither party was obligated to pay child support. Mother subsequently filed a petition to set support, as well as a motion for relief from the final decree, both of which sought to have the court set support in accordance with the child support guidelines. The court denied the petition and the motion on the grounds that the parties had agreed in the parenting plan that child support would not be paid and that a significant variance did not exist. Finding that relief to Mother is appropriate under the circumstances, we reverse the judgment and remand the case for further proceedings. | Maury County | Court of Appeals | 08/28/13 |  |
Patsy Freeman, Personal Representative & Administratrix of the Estate of John R. Freeman v. CSX Transportation, Inc. et al. M2012-01335-COA-R3-CV Authoring Judge: Judge Andy D. Bennett Trial Court Judge: Judge Franklin L. Russell After a lengthy trial, the trial court determined that the decedent was more than 50% at fault for the collision that resulted in his death. The evidence does not preponderate against the trial court’s findings and we therefore affirm. | Bedford County | Court of Appeals | 08/28/13 |  |
Rhonda Sue Watkins v. Kenneth Danny Watkins M2012-02378-COA-R3-CV Authoring Judge: Judge David R. Farmer Trial Court Judge: Judge Timothy L. Easter The trial court granted Father’s petition to modify child custody and child support, and denied Mother’s petition to increase alimony. Mother appeals. We vacate the trial court’s judgment with respect to Mother’s petition to modify alimony, and remand for findings of fact and further proceedings, if necessary. The remainder of the judgment is affirmed. | Williamson County | Court of Appeals | 08/28/13 |  |
Sandeep Gadhok v. Zameer Merchant W2012-01687-COA-R3-CV Authoring Judge: Judge David R. Farmer Trial Court Judge: Judge Jerry Stokes The trial court granted Defendant’s motion to dismiss for lack of prosecution. We affirm. | Shelby County | Court of Appeals | 08/28/13 |  |
Fred Barnes v. Herbert Hamm W2011-02288-COA-R3-CV Authoring Judge: Judge Holly M. Kirby Trial Court Judge: Judge Robert L. Childers This appeal concerns the circuit court’s dismissal of an appeal from the general sessions court. We dismiss the appeal for failure to comply with Rule 29 of the Tennessee Rules of Appellate Procedure. | Shelby County | Court of Appeals | 08/28/13 |  |
Wilma Ann Vance v. Donah Howard Arnold E2012-02252-COA-R3-CV Authoring Judge: Judge David R. Farmer Trial Court Judge: Judge John D. McAfee The trial court dismissed Husband’s post-judgment motion based on its conclusion that it lacked subject matter jurisdiction. We reverse. | Campbell County | Court of Appeals | 08/28/13 |  |

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »